pyscenarios: Python Scenario Generator
======================================

This package offers several modules used in Monte Carlo simulations:

:doc:`api/copula`
    Gaussian Copula, Student T* Copula and IT Copula samples generators
:doc:`api/sobol`
    Joe/Kuo Sobol series generator
:doc:`api/stats`
    Tail dependence measures

All modules fully support and are optimized for `dask <https://dask.org>`_
and are compatible with `dask distributed <http://distributed.dask.org>`_.


Index
-----

.. toctree::

   installing
   whats-new
   api/copula
   api/sobol
   api/stats

License
-------

pyscenarios is available under the open source `Apache License`__.

__ http://www.apache.org/licenses/LICENSE-2.0.html